--[[The main frame consists of a ParentFrame, a scrollable ContentFrame,
a X button to close the ParentFrame as well as a scollframe+scollbar]]

if(ThingsToDo2 == nil) then
	ThingsToDo2 = {}
end
local ttd2 = ThingsToDo2

if(ttd2.lib == nil) then
	ttd2.lib = {}
end
local lib = ttd2.lib

if(ttd2.frames == nil) then
	ttd2.frames = {}
end
local frames = ttd2.frames

frames.MainFrame = {}
local this = frames.MainFrame

this.IsVisible 			= false
this.ParentFrame 		= nil
this.Title				= nil
this.CloseButton 		= nil
this.CompletedCheckBox	= nil
this.DoneCheckBox		= nil
this.ScrollFrame 		= nil
this.ScrollBar			= nil
this.ContentFrame		= nil
this.ButtonSizeX		= 200
this.ButtonSizeY		= 50
this.NumButtons 		= 0
this.NumButtonsCap		= 8
this.Buttons = {}

function this.Create()

	--parent frame	
	this.ParentFrame = CreateFrame("Frame", nil, UIParent)
	this.ParentFrame:SetSize(250, 487)
	this.ParentFrame:SetPoint("CENTER")
	
	local border=this.ParentFrame:CreateTexture(nil,"BACKGROUND")
	border:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
	border:SetPoint("TOPLEFT",-5,5)
	border:SetPoint("BOTTOMRIGHT",5,-5)
	border:SetVertexColor(0.85, 0.85, 0.85, .5) 
	
	local body = this.ParentFrame:CreateTexture(nil, "ARTWORK")
	body:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
	body:SetAllPoints(this.ParentFrame)
	body:SetVertexColor(0.1, 0.1, 0.1, 1.0)
	
	this.ParentFrame:SetMovable(true)
	this.ParentFrame:EnableMouse(true)
	this.ParentFrame:RegisterForDrag("LeftButton")
	this.ParentFrame:SetScript("OnDragStart", this.ParentFrame.StartMoving)
	this.ParentFrame:SetScript("OnDragStop", this.ParentFrame.StopMovingOrSizing)
	
	--title
	this.Title = this.ParentFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
	this.Title:SetPoint("TOP", -10, -5)
	this.Title:SetText(ttd2.lib.chat.addonTitle())
	
	--close button
	this.CloseButton = CreateFrame("Button", nil, this.ParentFrame, "UIPanelButtonTemplate")
	this.CloseButton:SetPoint("TOPRIGHT", 0, 0)
	this.CloseButton:SetSize(25,25)
	this.CloseButton:SetText("x")
	this.CloseButton:SetScript("OnClick", this.Toggle)
	
	--completed checkbox
	this.CompletedCheckBox = CreateFrame("CheckButton", "TTD2_COMPLETED_CHECKBOX", this.ParentFrame, "ChatConfigCheckButtonTemplate")
	this.CompletedCheckBox:SetPoint("TOPLEFT", 15, -30)
	TTD2_COMPLETED_CHECKBOXText:SetText("include "..lib.chat.green("completed"))
	this.CompletedCheckBox.tooltip = "Print entries that have been completed permanently."
	this.CompletedCheckBox:SetScript("OnClick", ttd2.option.ToggleCompleted)
	this.CompletedCheckBox:SetChecked(ttd2.option.PrintCompleted)
	
	--done checkbox
	this.DoneCheckBox = CreateFrame("CheckButton", "TTD2_DONE_CHECKBOX", this.ParentFrame, "ChatConfigCheckButtonTemplate")
	this.DoneCheckBox:SetPoint("TOPLEFT", 15, -50)
	TTD2_DONE_CHECKBOXText:SetText("include "..lib.chat.red("done"))
	this.DoneCheckBox.tooltip = "Print entries that are not part of achievements/collections or have already been attempted and you now have lockout ID for them."
	this.DoneCheckBox:SetScript("OnClick", ttd2.option.ToggleDone)
	this.DoneCheckBox:SetChecked(ttd2.option.PrintDone)
	
	--scrollframe
	this.ScrollFrame = CreateFrame("ScrollFrame", nil, this.ParentFrame)
	this.ScrollFrame:SetPoint("TOPLEFT", this.ParentFrame, "TOPLEFT", 10, -75)
	this.ScrollFrame:SetPoint("BOTTOMRIGHT", this.ParentFrame, "BOTTOMRIGHT", -30, 10)
	--local texture = this.ScrollFrame:CreateTexture()
	--texture:SetAllPoints()
	--texture:SetColorTexture(.5,.5,.5,1)
	this.ParentFrame.scrollframe = this.ScrollFrame

	--scrollbar
	this.ScrollBar = CreateFrame("Slider", nil, this.ScrollFrame, "UIPanelScrollBarTemplate")
	this.ScrollBar:SetPoint("TOPRIGHT", this.ParentFrame, "TOPRIGHT", 0, -95)
	this.ScrollBar:SetPoint("BOTTOMRIGHT", this.ParentFrame, "BOTTOMRIGHT", 0, 20)
	this.ScrollBar:SetMinMaxValues(0, 0)
	this.ScrollBar:SetOrientation('VERTICAL')
	this.ScrollBar:SetValueStep(1)
	this.ScrollBar.scrollStep = 1
	this.ScrollBar:SetValue(0)
	this.ScrollBar:SetWidth(25)
	this.ScrollBar:SetScript(
		"OnValueChanged",
		function (self, value)
		self:GetParent():SetVerticalScroll(value)
		end)
	local scrollbg = this.ScrollBar:CreateTexture(nil, "BACKGROUND")
	scrollbg:SetAllPoints(this.ScrollBar)
	scrollbg:SetColorTexture(0, 0, 0, 0.4)
	this.ParentFrame.scrollbar = this.ScrollBar
	
	--content frame
	this.ContentFrame = CreateFrame("Frame", nil, this.ScrollFrame)
	this.ContentFrame:SetSize(210, 1000)
	this.ScrollFrame.content = this.ContentFrame
	this.ScrollFrame:SetScrollChild(this.ContentFrame)
	
	this.ParentFrame:Hide()
	
	this.ParentFrame:EnableMouseWheel(1)
	this.ParentFrame:SetScript(
		"OnMouseWheel",
		function (self, value)
			local ScrollMin, ScrollMax = this.ScrollBar:GetMinMaxValues();
			local ScrollStep = (ScrollMax - ScrollMin) / 20.0
			this.ScrollBar:SetValue(this.ScrollBar:GetValue()-(value*ScrollStep))
			end)
	
	return;
end

function this.AddButton(Text, Script)

	this.Buttons[this.NumButtons+1] = CreateFrame("Button", nil, this.ContentFrame, "UIPanelButtonTemplate")
	local Button = this.Buttons[this.NumButtons+1]
	
	Button:SetPoint("TOP", 0, -this.ButtonSizeY*this.NumButtons)
	Button:SetSize(this.ButtonSizeX,this.ButtonSizeY)
	Button:SetText(Text)
	Button:SetScript("OnClick", Script)
	
	this.NumButtons = this.NumButtons + 1
	if(this.NumButtons > this.NumButtonsCap) then
		local ScrollMin, ScrollMax = this.ScrollBar:GetMinMaxValues();
		this.ScrollBar:SetMinMaxValues(ScrollMin, ScrollMax+this.ButtonSizeY)
	end
	
	return
end

function this.Toggle()	
	if(this.IsVisible == true) then
		this.ParentFrame:Hide()
		this.IsVisible = false
	else
		this.ParentFrame:Show()
		this.IsVisible = true
	end
	
	return;
end
