if(ThingsToDo2 == nil) then
	ThingsToDo2 = {}
end
local ttd2 = ThingsToDo2

if(ttd2.option == nil) then
	ttd2.option = {}
end
local option = ttd2.option

if(ttd2.lib == nil) then
	ttd2.lib = {}
end
local lib = ttd2.lib

--this module
lib.journal = {}
local this = lib.journal

this.private = { set = false }
function this.private.Validate()
	if(this.private.set == false) then
		this.private.init()
	end
	return
end

function this.private.init()
	if(this.private.set) then
		return
	end
	
	--private data
	this.private.data = {}
	this.private.data.difficulties = {}
	for i=1,34 do
		local difficultyInfo = {GetDifficultyInfo(i)}
		this.private.data.difficulties[i] = difficultyInfo[1]
	end
	
	
	this.private.data.instances = {}
	this.private.data.encounters = {}	
	this.private.data.mounts = {}
	this.private.data.pets = {}
	this.private.data.toys = {}
	
	this.private.set = true
end

--public namespaces for functions
this.instance = {}
this.encounter = {}
this.mount = {}
this.pet = {}
this.toy = {}

function this.instance.AddByID(id)
	this.private.Validate()
	
	if(this.private.data.instances[id] ~= nil) then
		return false
	end
	
	local instanceInfo = {EJ_GetInstanceInfo(id)}
	this.private.data.instances[id] = 
	{
		name = instanceInfo[1]
	}
	return true
end

function this.instance.GetNameByID(id)
	this.private.Validate()
	
	this.private.instance.AddByID(id)
	
	return this.private.data.instances[id].name
end

function this.instance.GetDiffText(diff)
	this.private.Validate()
	
	if(this.private.data.difficulties[diff] == nil) then
		lib.chat.error("invalid difficulty requested")
	end
	
	return this.private.data.difficulties[diff]
end

function this.instance.GetLinkByIDDiff(id, diff)
	this.private.Validate()

	this.private.instance.AddByID(id)
	
	return ("\124cFF66BBFF\124Hjournal:0:"..id..":"..diff.."\124h["..this.private.data.instances[id].name.."]\124h\124r")
end

function this.encounter.AddByID(id)
	this.private.Validate()
	
	if(this.private.data.encounters[id] ~= nil) then
		return false
	end
	
	local encounterInfo = {EJ_GetEncounterInfo(id)}
	this.private.data.encounters[id] = 
	{
		name = encounterInfo[1]
	}
	return true
end

function this.encounter.GetNameByID(id)
	this.private.Validate()
	
	this.private.encounter.AddByID(id)
	
	return this.private.data.encounters[id].name
end

function this.encounter.getLinkByIdDiff(id, diff)
	this.private.Validate()

	this.private.encounter.AddByID(id)
	
	return ("\124cFF66BBFF\124Hjournal:1:"..id..":"..diff.."\124h["..this.private.data.encounters[id].name.."]\124h\124r")
end

function this.mount.AddByID(ID)
	this.private.Validate()
	
	--adding a mount multiple times must be allowed since different modules might do it
	if(this.private.data.mounts[ID] ~= nil) then
		return
	end
	
	this.private.data.mounts[ID] = {}
	this.mount.UpdateByID(ID)
	return
end

function this.mount.UpdateByID(ID)
	this.private.Validate()

	if(this.private.data.mounts[ID] == nil) then
		lib.chat.error("trying to update mount before adding it: "..ID)
		return
	end
	
	local mountInfo = { C_MountJournal.GetMountInfoByID(ID) }
	this.private.data.mounts[ID] = 
	{
		name = mountInfo[1],
		faction = mountInfo[9],
		isCollected = mountInfo[11]
	}
end

function this.mount.GetByID(ID)
	this.private.Validate()
	
	if(this.private.data.mounts[ID] == nil) then
		lib.chat.error("trying to access mount before adding it: "..ID)
		return
	end
	
	return this.private.data.mounts[ID]
end

function this.pet.AddByID(id)
	this.private.Validate()
	
	if(this.private.data.pets[id] ~= nil) then
		return false
	end
	
	this.private.data.pets[id] = {}
	this.pet.updateById(id)
	return true
end

function this.pet.updateById(id)
	this.private.Validate()

	if(this.private.pet.AddByID(id) == true) then
		return
	end
	
	local pet = this.private.data.pets[id]
	
	if(pet.name == nil) then
		local petInfo = { C_PetJournal.GetPetInfoBySpeciesID(id) }
		pet.name = petInfo[1]
	end
	
	local numCollected = { C_PetJournal.GetNumCollectedInfo(id) }
	pet.numCollected = numCollected[1]
	pet.isCollected = (numCollected[1] ~= 0)
end

function this.pet.GetByID(id)
	this.private.Validate()
	
	this.private.pet.AddByID(id)
	
	return this.private.data.pets[id]
end

function this.toy.AddByID(ID)
	this.private.Validate()
	
	--adding a toy multiple times must be allowed since different modules might do it
	if(this.private.data.toys[ID] ~= nil) then
		return
	end
	
	this.private.data.toys[ID] = {}
	this.toy.UpdateByID(ID)
	return true
end

function this.toy.UpdateById(ID)
	this.private.Validate()

	if(this.private.data.toys[ID] == nil) then
		lib.chat.error("trying to update toy before adding it: "..ID)
		return
	end
	
	local toy = this.private.data.toys[ID]
	
	if(toy.name == nil) then
		local toyInfo = { C_ToyBox.GetToyInfo(ID) }
		toy.name = toyInfo[2]
	end
	
	if(toy.isCollected ~= true) then
		toy.isCollected = PlayerHasToy(ID)
	end
end

function this.toy.GetByID(id)
	this.private.Validate()
	
	if(this.private.data.toys[ID] == nil) then
		lib.chat.error("trying to access toy before adding it: "..ID)
		return
	end
	
	return this.private.data.toys[id]
end
